VisionFive2 Linux kernel

StarFive Tech Linux Kernel for VisionFive (JH7110) boards (mirror)

More than 9999 Commits   32 Branches   54 Tags
author: Michał Mirosław <mirq-linux@rere.qmqm.pl> 2021-07-26 10:30:56 +0200 committer: Greg Kroah-Hartman <gregkh@linuxfoundation.org> 2021-09-03 10:23:00 +0200 commit: ef3738a60d1826a46e6fdc4e8dc037705b32693c parent: 184caa4f8b83add4b988edcf8b02ab4cc2f3ecc9
Commit Summary:
opp: remove WARN when no valid OPPs remain
Diffstat:
1 file changed, 3 insertions, 2 deletions
diff --git a/drivers/opp/of.c b/drivers/opp/of.c
index c582a9ca397b..01feeba78426 100644
--- a/drivers/opp/of.c
+++ b/drivers/opp/of.c
@@ -985,8 +985,9 @@ static int _of_add_opp_table_v2(struct device *dev, struct opp_table *opp_table)
 		}
 	}
 
-	/* There should be one of more OPP defined */
-	if (WARN_ON(!count)) {
+	/* There should be one or more OPPs defined */
+	if (!count) {
+		dev_err(dev, "%s: no supported OPPs", __func__);
 		ret = -ENOENT;
 		goto remove_static_opp;
 	}